summaryrefslogtreecommitdiffstats
path: root/src/kicondialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/kicondialog.h')
-rw-r--r--src/kicondialog.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/kicondialog.h b/src/kicondialog.h
index 3cd4866..da43b74 100644
--- a/src/kicondialog.h
+++ b/src/kicondialog.h
@@ -50,11 +50,11 @@ public:
/**
* Constructs an icon selection dialog using the global iconloader.
*/
- KIconDialog(TQWidget *tqparent=0L, const char *name=0L);
+ KIconDialog(TQWidget *parent=0L, const char *name=0L);
/**
* Constructs an icon selection dialog using a specific iconloader.
*/
- KIconDialog(KIconLoader *loader, TQWidget *tqparent=0,
+ KIconDialog(KIconLoader *loader, TQWidget *parent=0,
const char *name=0);
/**
* Destructs the dialog.
@@ -157,7 +157,7 @@ public:
* @param iconSize the size of the icons -- the default of the icongroup
* if set to 0
* @param user Begin with the "user icons" instead of "system icons".
* @param tqparent The tqparent widget of the dialog.
* @param caption The caption to use for the dialog.
* @return The name of the icon, suitable for loading with KIconLoader.
* @version New in 3.0
@@ -165,7 +165,7 @@ public:
static TQString getIcon(KIcon::Group group=KIcon::Desktop,
KIcon::Context context=KIcon::Application,
bool strictIconSize=false, int iconSize = 0,
- bool user=false, TQWidget *tqparent=0,
+ bool user=false, TQWidget *parent=0,
const TQString &caption=TQString());
signals:
@@ -229,12 +229,12 @@ public:
/**
* Constructs a KIconButton using the global iconloader.
*/
- KIconButton(TQWidget *tqparent=0L, const char *name=0L);
+ KIconButton(TQWidget *parent=0L, const char *name=0L);
/**
* Constructs a KIconButton using a specific KIconLoader.
*/
- KIconButton(KIconLoader *loader, TQWidget *tqparent, const char *name=0L);
+ KIconButton(KIconLoader *loader, TQWidget *parent, const char *name=0L);
/**
* Destructs the button.
*/
@@ -157,7 +157,7 @@ public:
* if set to 0
* @param user Begin with the "user icons" instead of "system icons".
- * @param tqparent The tqparent widget of the dialog.
+ * @param parent The parent widget of the dialog.
* @param caption The caption to use for the dialog.
* @return The name of the icon, suitable for loading with KIconLoader.